"""Common filenames and locations for topographic data, meshes and outputs.
Also includes origin for slump scenario.
"""

from os import sep, environ, getenv, getcwd
from os.path import expanduser, basename
#from anuga.utilities.polygon import read_polygon
import sys
from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
from time import localtime, strftime
from anuga.geospatial_data.geospatial_data import *

#Making assumptions about the location of scenario data
state = 'western_australia'
scenario_dir_name = 'pt_hedland_tsunami_scenario_2006'

# onshore data from 30m DTED level 2
onshore_name_dted = 'pt_hedland_onshore_30m_dted' # get from Neil/Ingo (DEM or topo data)
onshore_name_dli = 'pt_hedland_onshore_20m_dli' # get from Neil/Ingo (DEM or topo data)

# offshore data from GA digitised charts
offshore_name1 = 'pt_hedland_offshore_points_orig'

# offshore data from AHO fairsheets
offshore_name2 = 'pt_hedland_offshore_points_fairsheet_orig'

# reissued offshore data from PMD and NM&I Nov 2006
offshore_name0 = 'hydrographic_charts'
offshore_name1 = 'xy100003817'
offshore_name2 = 'xy100003819'
offshore_name3 = 'xy100003822'
offshore_name4 = 'xy100003824'
offshore_name5 = 'xy100003825'
offshore_name6 = 'xy100003826'
offshore_name7 = 'xy100003827'
offshore_name8 = 'xy100003828'
offshore_name9 = 'xy100003829'
offshore_name10 = 'xy100003830'
offshore_name11 = 'xy100003831'
offshore_name12 = 'xy100003832'
offshore_name13 = 'xy100003837'
offshore_name14 = 'xy100003838'
offshore_name15 = 'xy100003840'
offshore_name16 = 'xy100003841'
offshore_name17 = 'xy100003843'
offshore_name18 = 'xy100003845'
offshore_name19 = 'xy100003846'
offshore_name20 = 'xy100003847'
offshore_name21 = 'xy100003945'
offshore_name22 = 'xy100003946'
offshore_name23 = 'xy100003947'
offshore_name24 = 'xy100003948'
offshore_name25 = 'xy100004071'
offshore_name26 = 'xy100004072'
offshore_name27 = 'xy100004074'
offshore_name28 = 'xy100004078'
offshore_name29 = 'xy100004079'
offshore_name30 = 'xy100004080'
offshore_name31 = 'xy100004081'
offshore_name32 = 'xy100004082'
offshore_name33 = 'xy100004083'
offshore_name34 = 'xy100004084'
offshore_name35 = 'xy100004085'
offshore_name36 = 'xy100004086'
offshore_name37 = 'xy100004087'
offshore_name38 = 'xy100004088'
offshore_name39 = 'xy100004089'
offshore_name40 = 'xy100004090'
offshore_name41 = 'xy100011753'
offshore_name42 = 'xy100014967'
offshore_name43 = 'xy100014968'
offshore_name44 = 'xy100014969'
offshore_name45 = 'xy100021030'
offshore_name46 = 'xy100021031'
offshore_name47 = 'xy100021032'
offshore_name48 = 'xy100021033'
offshore_name49 = 'xy100021035'
offshore_name50 = 'xy100022767'

# coastline developed from aerial photography and 1.5m DLI contour
#coast_name = 'pt_hedland_coastline_points_dted2_new'
coast_name = 'coast_with_extracted_z'


boundary_basename = 'SU-AU_clip'

#swollen/ all data output
basename = 'source'

codename = 'project.py'

if sys.platform == 'win32':
    home = getenv('INUNDATIONHOME') #Sandpit's parent dir
#    python_home = getenv('PWD')     
    user = getenv('USERPROFILE')
    #print 'USER:', user
else:
    # original
    #home = getenv('INUNDATIONHOME', sep+'d'+sep+'cit'+sep+'1'+sep+'cit'+sep+'risk_assessment_methods_project'+sep+'inundation')
    # update to perlite 2
    home = getenv('INUNDATIONHOME', sep+'d'+sep+'cit'+sep+'2'+sep+'cit'+sep+'inundation'+sep+'data')     
    user = getenv('LOGNAME')

# INUNDATIONHOME is the inundation directory, not the data directory.
home += sep +'data'

#Derive subdirectories and filenames
time = strftime('%Y%m%d_%H%M%S',localtime()) #gets time for new dir
outputtimedir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'outputs'+sep+time+sep

#print 'outputtimedir', outputtimedir
#meshdir = home+sep+scenario_dir_name+sep+'meshes'+sep
#datadir = home+sep+scenario_dir_name+sep+'topographies'+sep
#gaugedir = home+sep+scenario_dir_name+sep+'gauges'+sep
#polygondir = home+sep+scenario_dir_name+sep+'polygons'+sep
#boundarydir = home+sep+scenario_dir_name+sep+'boundaries'+sep
#outputdir = home+sep+scenario_dir_name+sep+'outputs'+sep
#tidedir = home+sep+scenario_dir_name+sep+'tide_data'+sep

meshdir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'meshes'+sep
datadir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'topographies'+sep
gaugedir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'gauges'+sep
polygondir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'polygons'+sep
boundarydir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'boundaries'+sep
outputdir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'outputs'+sep
tidedir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'tide_data'+sep

gauge_filename = gaugedir + 'gauge_location_port_hedland.csv'
beach_gauges = gaugedir + 'beach_gauges.csv'
gauge_checking = gaugedir + 'gauge_checking_test.csv'
buildings_filename = gaugedir + 'Port_Hedland_res_Project.csv'
buildings_filename_out = 'Port_Hedland_res_Project_modified.csv'
community_filename = gaugedir + 'CHINS_v2.csv'
community_scenario = gaugedir + 'community_pt_hedland.csv'
tidal_filename = tidedir + 'pt_hedland_tide.txt'

meshname = meshdir + basename
#onshore_dem_name = datadir + onshore_name_dted
onshore_dem_name = datadir + onshore_name_dli
offshore_dem_name0 = datadir + offshore_name0
offshore_dem_name1 = datadir + offshore_name1
offshore_dem_name2 = datadir + offshore_name2
offshore_dem_name3 = datadir + offshore_name3
offshore_dem_name4 = datadir + offshore_name4
offshore_dem_name5 = datadir + offshore_name5
offshore_dem_name6 = datadir + offshore_name6
offshore_dem_name7 = datadir + offshore_name7
offshore_dem_name8 = datadir + offshore_name8
offshore_dem_name9 = datadir + offshore_name9
offshore_dem_name10 = datadir + offshore_name10
offshore_dem_name11 = datadir + offshore_name11
offshore_dem_name12 = datadir + offshore_name12
offshore_dem_name13 = datadir + offshore_name13
offshore_dem_name14 = datadir + offshore_name14
offshore_dem_name15 = datadir + offshore_name15
offshore_dem_name16 = datadir + offshore_name16
offshore_dem_name17 = datadir + offshore_name17
offshore_dem_name18 = datadir + offshore_name18
offshore_dem_name19 = datadir + offshore_name19
offshore_dem_name20 = datadir + offshore_name20
offshore_dem_name21 = datadir + offshore_name21
offshore_dem_name22 = datadir + offshore_name22
offshore_dem_name23 = datadir + offshore_name23
offshore_dem_name24 = datadir + offshore_name24
offshore_dem_name25 = datadir + offshore_name25
offshore_dem_name26 = datadir + offshore_name26
offshore_dem_name27 = datadir + offshore_name27
offshore_dem_name28 = datadir + offshore_name28
offshore_dem_name29 = datadir + offshore_name29
offshore_dem_name30 = datadir + offshore_name30
offshore_dem_name31 = datadir + offshore_name31
offshore_dem_name32 = datadir + offshore_name32
offshore_dem_name33 = datadir + offshore_name33
offshore_dem_name34 = datadir + offshore_name34
offshore_dem_name35 = datadir + offshore_name35
offshore_dem_name36 = datadir + offshore_name36
offshore_dem_name37 = datadir + offshore_name37
offshore_dem_name38 = datadir + offshore_name38
offshore_dem_name39 = datadir + offshore_name39
offshore_dem_name40 = datadir + offshore_name40
offshore_dem_name41 = datadir + offshore_name41
offshore_dem_name42 = datadir + offshore_name42
offshore_dem_name43 = datadir + offshore_name43
offshore_dem_name44 = datadir + offshore_name44
offshore_dem_name45 = datadir + offshore_name45
offshore_dem_name46 = datadir + offshore_name46
offshore_dem_name47 = datadir + offshore_name47
offshore_dem_name48 = datadir + offshore_name48
offshore_dem_name49 = datadir + offshore_name49
offshore_dem_name50 = datadir + offshore_name50

coast_dem_name = datadir + coast_name
combined_dem_name = datadir + 'pt_hedland_combined_elevation'
outputname = outputtimedir + basename  #Used by post processing

community_filename = gaugedir + 'CHINS_v2.csv'
community_pt_hedland = gaugedir + 'community_pt_hedland.csv'

# clipping region to make DEM (pts file) from onshore data
eastingmin = 594000
eastingmax = 715000
northingmin = 7720000
northingmax = 7880000

# for ferret2sww
south = degminsec2decimal_degrees(-20,30,0)
north = degminsec2decimal_degrees(-17,10,0)
west = degminsec2decimal_degrees(117,00,0)
east = degminsec2decimal_degrees(120,00,0)

# region to export (used from export_results.py)
e_min_area = 648000
e_max_area = 675000
n_min_area = 7745000
n_max_area = 7761000

export_region = [[e_min_area,n_min_area],[e_min_area,n_max_area],[e_max_area,n_max_area],[e_max_area,n_min_area]]
                 
refzone = 50 

from anuga.coordinate_transforms.redfearn import redfearn
# boundary up to 50 m contour
lat1_50 = degminsec2decimal_degrees(-19,20,0)
lat2_50 = degminsec2decimal_degrees(-19,30,0)
lat3_50 = degminsec2decimal_degrees(-19,45,0)
lon1_50 = degminsec2decimal_degrees(119,05,0)
lon2_50 = degminsec2decimal_degrees(118,20,0)
lon3_50 = degminsec2decimal_degrees(117,45,0)
z, easting, northing = redfearn(lat1_50, lon1_50)
d0_50 = [easting, northing]
z, easting, northing = redfearn(lat2_50, lon2_50)
d1_50 = [easting, northing]
z, easting, northing= redfearn(lat3_50, lon3_50)
d2_50 = [easting, northing]

d4_50 = [285000, 7585000]
d6_50 = [330000, 7605000]
#bounding_poly50 = [p0_50, p1_50, p2_50, d6_50, d5, d4_50]

d0 = [763852.0, 7934358.0]
d1 = [710987.0, 7925797.0]
d2 = [658264.0, 7926314.0]
d3 = [552686.0, 7871580.0]
#d4 = [604415.81, 7733013.56]
d4 = [638000.0, 7733013.56]
#d5 = [656561.15, 7732615.11]
d5 = [662000.0, 7732615.11]
#d6 = [708940.32, 7750510.33]
d6 = [690000.0, 7740510.33]
#polyAll = [d0, d1, d2, d3, d4, d5, d6]
#polyAll = [d0_50, d1_50, d2_50, d4, d5, d6]
# from Hamish
h0=[629262.17, 7747205.47]
h1=[552686.00, 7871579.99] #d3
h2=[658264.00, 7926314.00] #d2
h3=[710986.99, 7925796.99] #d1
h4=[763851.99, 7934357.99] #d0
h5=[701485.21, 7770656.86]
h6=[698273.75, 7762227.38]
h7=[698194.23, 7762018.65]
h8=[691627.41, 7744781.98]
h9=[679220.75, 7743604.59]
h10=[653512.59, 7740528.56]
h11=[634777.71, 7738247.17]
h12=[629443.86, 7746910.37]
h13=[629396.84, 7746986.75]
h14=[629352.32, 7747059.06]
h15=[629276.24, 7747182.63]
h16=[629262.17, 7747205.47] #repeat of h0
# using Hamish's new bounding polygon
#polyAll = [d0_50, d1_50, d2_50, h16,h15,h14,h13,h12,h11,h10,h9,h8,h7,h6,h5]
polyAll = [d0_50, d1_50, d2_50, h16,h11,h8,h6, h5]

#Interior region - Pt Hedland town
i0 = [668000, 7757000]
i1 = [659000, 7755000]
i2 = [660000, 7749000]
i3 = [667000, 7746000]
i4 = [678000, 7751000]

poly_pt_hedland = [i0, i1, i2, i3, i4]

#Are there other significant features?
j0 = [670000, 7760000]
j1 = [633000, 7745000]
j2 = [665000, 7743000]
j3 = [690000, 7755000]

poly_region = [j0, j1, j2, j3]
